TBLWebView class

Inheritance

Constructors

TBLWebView(TBLWebViewManager _webViewManager, ScrollController scrollController, TBLWebviewController _webViewController, bool _isFeed)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isScrollSwitchTurnedOff → bool
no setter
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TBLWebView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
fixIOSAutoScroll(bool isFeed) → void
getPositionOnScreen(BuildContext buildContext) → Offset
Returns the offset from screen top (and left?) when the WebView is close to screen top the offset.dy will return close to 0 result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollListener(ScrollController controller, bool isFeed, BuildContext buildContext, double webViewHeight) → void
An update event called from outside this WebView. This is where screen measurements decide if to enable our scroll switch logic.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
widgetInViewport(Offset position) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited