TBLWebviewController class

Implemented types

Constructors

TBLWebviewController.create(String mode, String placement, String pageUrl, String pageType, String pageId, String targetType, int viewId, String publisherId, TBLClassicListener taboolaStandardListener, PlatformWebViewControllerCreationParams platformWebViewControllerCreationParams)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isKeepAlive → dynamic
no setter
isLoadWebviewWidget ↔ bool
getter/setter pair
mode → String
final
onWebviewResizeListener ↔ dynamic Function(String placement, double height)?
getter/setter pair
pageId → String
final
pageType → String
final
pageUrl → String
final
placement → String
final
platform → PlatformWebViewController
Implementation of PlatformWebViewController for the current platform.
finalinherited
platformWebViewControllerCreationParams → PlatformWebViewControllerCreationParams
final
publisherId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetType → String
final
viewId → int
final
webViewHeight ↔ double
getter/setter pair

Methods

addJavaScriptChannel(String name, {required void onMessageReceived(JavaScriptMessage)}) → Future<void>
Adds a new JavaScript channel to the set of enabled channels.
inherited
addJavaScriptMessageHandler({required void callback(dynamic)}) → Future<void>
override
canGoBack() → Future<bool>
Checks whether there's a back history item.
inherited
canGoForward() → Future<bool>
Checks whether there's a forward history item.
inherited
clearCache() → Future<void>
Clears all caches used by the WebView.
inherited
clearLocalStorage() → Future<void>
Clears the local storage used by the WebView.
inherited
currentUrl() → Future<String?>
Returns the current URL that the WebView is displaying.
inherited
enableZoom(bool enabled) → Future<void>
Whether to support zooming using the on-screen zoom controls and gestures.
inherited
fetchContent() → Future<void>
We use this method to fetch the content of the webview, this method using the loadRequest method from the webview controller to load the webview url.
getScrollPosition() → Future<Offset>
Returns the current scroll position of this view.
inherited
getTitle() → Future<String?>
The title of the currently loaded page.
inherited
getUserAgent() → Future<String?>
Gets the value used for the HTTP User-Agent: request header.
inherited
goBack() → Future<void>
Goes back in the history of this WebView.
inherited
goForward() → Future<void>
Goes forward in the history of this WebView.
inherited
loadFile(String absoluteFilePath) → Future<void>
Loads the file located on the specified absoluteFilePath.
inherited
loadFlutterAsset(String key) → Future<void>
Loads the Flutter asset specified in the pubspec.yaml file.
inherited
loadHtmlString(String html, {String? baseUrl}) → Future<void>
Loads the supplied HTML string.
inherited
loadRequest(Uri uri, {LoadRequestMethod method = LoadRequestMethod.get, Map<String, String> headers = const <String, String>{}, Uint8List? body}) → Future<void>
Makes a specific HTTP request and loads the response in the webview.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() → Future<void>
Reloads the current URL.
inherited
removeJavaScriptChannel(String javaScriptChannelName) → Future<void>
Removes the JavaScript channel with the matching name from the set of enabled channels.
inherited
removeJavaScriptMessageHandler() → void
override
reset() → void
resizeWebview(String placement, double height) → void
passed to the webviewManager that get triggered by the ML when the webview is resized
runJavaScript(String javascript) → Future<void>
Runs the given JavaScript in the context of the current page.
runJavaScriptReturningResult(String javaScript) → Future<Object>
Runs the given JavaScript in the context of the current page, and returns the result.
inherited
scrollBy(int x, int y) → Future<void>
Moves the scrolled position of this view.
inherited
scrollTo(int x, int y) → Future<void>
Sets the scrolled position of this view.
inherited
setBackgroundColor(Color color) → Future<void>
Sets the current background color of this view.
inherited
setHorizontalScrollBarEnabled(bool enabled) → Future<void>
Whether the horizontal scrollbar should be drawn or not.
inherited
setInspectable(bool inspectable) → Future<void>
Enables/disables Safari Web Inspector debugging for the WKWebView on iOS (requires iOS 16.4+). The publisher opts in via the debugModeInspectableWebView extra property.
override
setIsKeepAlive(bool value) → dynamic
setJavaScriptMode(JavaScriptMode javaScriptMode) → Future<void>
Sets the JavaScript execution mode to be used by the WebView.
inherited
setNavigationDelegate(NavigationDelegate delegate) → Future<void>
Sets the NavigationDelegate containing the callback methods that are called during navigation events.
inherited
setOnConsoleMessage(void onConsoleMessage(JavaScriptConsoleMessage message)) → Future<void>
Sets a callback that notifies the host application on any log messages written to the JavaScript console.
inherited
setOnJavaScriptAlertDialog(Future<void> onJavaScriptAlertDialog(JavaScriptAlertDialogRequest request)) → Future<void>
Sets a callback that notifies the host application that the web page wants to display a JavaScript alert() dialog.
inherited
setOnJavaScriptConfirmDialog(Future<bool> onJavaScriptConfirmDialog(JavaScriptConfirmDialogRequest request)) → Future<void>
Sets a callback that notifies the host application that the web page wants to display a JavaScript confirm() dialog.
inherited
setOnJavaScriptTextInputDialog(Future<String> onJavaScriptTextInputDialog(JavaScriptTextInputDialogRequest request)) → Future<void>
Sets a callback that notifies the host application that the web page wants to display a JavaScript prompt() dialog.
inherited
setOnScrollPositionChange(void onScrollPositionChange(ScrollPositionChange change)?) → Future<void>
Sets a listener for scroll position changes.
inherited
setOverScrollMode(WebViewOverScrollMode mode) → Future<void>
Sets the over-scroll mode for the WebView.
inherited
setUserAgent(String? userAgent) → Future<void>
Sets the value used for the HTTP User-Agent: request header.
inherited
setVerticalScrollBarEnabled(bool enabled) → Future<void>
Whether the vertical scrollbar should be drawn or not.
inherited
supportsSetScrollBarsEnabled() → Future<bool>
Returns true if the current platform supports setting whether scrollbars should be drawn or not.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited