TBLWebViewManager class

Mixed-in types

Constructors

TBLWebViewManager({required GlobalKey<State<StatefulWidget>> key, required TblBaseWebviewController tblBaseWebviewController, required HashMap<String, TBLExtraPropertyWithLevel> unitExtraProperties, required TBLTrackingManager trackingManager, required TBLIntegrationType integrationType, required void didOnAdReceiveSuccess(String), required void didResize(String, double), required void didFailToLoad(String, String), required bool didClickOnItem(String, String, String, bool)})

Properties

didClickOnItem bool Function(String, String, String, bool)
final
didFailToLoad → void Function(String, String)
final
didOnAdReceiveSuccess → void Function(String)
final
didResize → void Function(String, double)
final
handlers Map<String, Function>
latefinal
hashCode int
The hash code for this object.
no setterinherited
integrationType TBLIntegrationType
The integration type this manager reports under the sdkt device data field.
no setter
isScrollSwitchTurnedOff bool
no setter
key GlobalKey<State<StatefulWidget>>
final
nativeWindowRect Rect
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tblBaseWebviewController TblBaseWebviewController
final
tblRectUtils TBLRectUtils
final
tblWebViewDidScrollToTop ↔ void Function()?
getter/setter pair
webViewRect Rect
getter/setter pair

Methods

didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
inherited
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
override
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
dispose() → void
fetchContent() → void
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleScroll() → void
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyExternalRects() → void
openItemBrowser(String url) Future<void>
selfPopulateExtraProperties(HashMap<String, String> uniExtraProperties) Future<void>
toString() String
A string representation of this object.
inherited
updateRects() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

TAG → const String