TBLPackageInfoData class

Constructors

TBLPackageInfoData({required String appName, required String packageName, required String version})

Properties

appName → String
CFBundleDisplayName/CFBundleName iOS, application/label Android.
final
hashCode → int
The hash code for this object.
no setterinherited
packageName → String
bundleIdentifier iOS, getPackageName Android.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
CFBundleShortVersionString iOS, versionName Android.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited