InlineMediaPlaybackWarner mixin

Shared behavior for TblBaseWebviewController implementers that can check their controller's inline media playback configuration.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
warnIfInlineMediaPlaybackNotConfigured(bool allowsInlineMediaPlayback) → void
This flag was added after publishers reported issues with Motion Ads playing automatically and opening all over the screen.

Operators

operator ==(Object other) bool
The equality operator.
inherited