warnIfInlineMediaPlaybackNotConfigured method

void warnIfInlineMediaPlaybackNotConfigured(
  1. bool allowsInlineMediaPlayback
)

This flag was added after publishers reported issues with Motion Ads playing automatically and opening all over the screen.

Implementation

void warnIfInlineMediaPlaybackNotConfigured(bool allowsInlineMediaPlayback) {
  if (!allowsInlineMediaPlayback) {
    TBLLogger.log(
        'InlineMediaPlaybackWarner | warnIfInlineMediaPlaybackNotConfigured | '
        'WARNING: allowsInlineMediaPlayback is not set to true on this WebView controller. '
        'Videos may not play inline on iOS. Please configure your controller with '
        'allowsInlineMediaPlayback: true as shown in the SDK documentation.');
  }
}