TblBaseWebviewController class abstract

Implementers

Constructors

TblBaseWebviewController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addJavaScriptMessageHandler({required void callback(dynamic)}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeJavaScriptMessageHandler() → void
runJavaScript(String javascript) Future<void>
setInspectable(bool inspectable) Future<void>
Enables/disables Safari Web Inspector debugging for the underlying WKWebView on iOS (requires iOS 16.4+).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited