TBLFlutterWebViewControllerWrapper class

A wrapper class that implements TblBaseWebviewController for Flutter WebView

Implemented types
Mixed-in types

Constructors

TBLFlutterWebViewControllerWrapper(WebViewController controller)
Creates a new TBLFlutterWebViewControllerWrapper instance

Properties

controller → WebViewController
The underlying Flutter WebViewController instance
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addJavaScriptMessageHandler({required void callback(dynamic)}) Future<void>
override
checkInlineMediaPlaybackConfiguration() Future<void>
allowsInlineMediaPlayback (iOS) is a WebView creation-time param the publisher must set themselves when building this controller - we can't set it after the fact. Warn loudly if it looks misconfigured so publishers can fix their setup.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeJavaScriptMessageHandler() → void
override
runJavaScript(String javascript) Future<void>
override
setInspectable(bool inspectable) Future<void>
Enables/disables Safari Web Inspector debugging for the underlying WKWebView on iOS (requires iOS 16.4+).
override
toString() String
A string representation of this object.
inherited
warnIfInlineMediaPlaybackNotConfigured(bool allowsInlineMediaPlayback) → void
This flag was added after publishers reported issues with Motion Ads playing automatically and opening all over the screen.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited