checkInlineMediaPlaybackConfiguration method
allowsInlineMediaPlayback (iOS) is a WebView creation-time param the publisher must set themselves when building this controller - we can't set it after the fact. Warn loudly if it looks misconfigured so publishers can fix their setup.
Implementation
Future<void> checkInlineMediaPlaybackConfiguration() async {
final params = controller.platform.params;
if (params is WebKitWebViewControllerCreationParams) {
warnIfInlineMediaPlaybackNotConfigured(params.allowsInlineMediaPlayback);
}
}